@@ -22,9 +22,25 @@ pub enum ViewerError {
     #[error("URL path must start with `/`")]
     UrlMustStartWithSlash,
 
+    /// Remedy: restart with `--debug trace` and make sure that
+    /// no local process is attacking our HTTP server.
+    /// If there are good reasons to allow more connections,
+    /// raise the value `tcp_connections_max` in the
+    /// configuration file.
+    #[error(
+        "Maximum open TCP connections ({max_conn}) exceeded. \
+         Can not handle request. Consider raising the configuration variable \
+         `tcp_connections_max` in the configuration file."
+    )]
+    TcpConnectionsExceeded { max_conn: usize },
+
     /// Network error.
-    #[error("Can not read from TCP stream.")]
-    StreamRead { source_str: String },
+    #[error("Can not read TCP stream: {error}")]
+    StreamRead { error: std::io::Error },
+
+    /// Network error.
+    #[error("Can not parse HTTP header in TCP stream: {source_str}")]
+    StreamParse { source_str: String },
 
     /// Remedy: check `browser_args` configuration file variable.
     #[error("Error executing external application.")]
